@@ -17,14 +17,10 @@
 
 int main(int argc, char *argv[])
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
     QApplication app(argc, argv);
     app.setDesktopFileName(QStringLiteral("org.kde.mboximporter"));
     KCrash::initialize();
-    KLocalizedString::setApplicationDomain("mboximporter");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("mboximporter"));
 
     KAboutData aboutData(QStringLiteral("mboximporter"),
                          i18n("MBox importer tool"),
